//
//  AppController.m
//  Drupal XML-RPC Demo
//
//  Created by Justin R. Miller on 4/3/07.
//  Copyright 2007 Code Sorcery Workshop. All rights reserved.
//

#import "AppController.h"
#import "DragableImageView.h"
#import "WebServicesWrapper.h"

@implementation AppController

- (void)awakeFromNib
{
    [mainWindow center];
    [prefsWindow center];
    
    [mainWindow setBackgroundColor:[NSColor colorWithCalibratedRed:1.0 green:1.0 blue:0.75 alpha:1.0]];
    
    [self clickedClearPasteboard:self];
}

- (IBAction)clickedUploadImage:(id)sender
{
    if ([[[dropZone draggedImage] representations] objectAtIndex:0] == nil) {
        [[NSSound soundNamed:@"Basso"] play];
        return;
    }
    
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    
    NSString *gateway = [[defaults stringForKey:@"SiteURL"] stringByAppendingString:@"/xmlrpc.php"];
    
    NSURL *url = [NSURL URLWithString:gateway];
    
    NSString *method = @"asset.add";
    
    NSString *username = [defaults stringForKey:@"Username"];
    NSString *password = [defaults stringForKey:@"Password"];
    
    NSData *content;
    
    if ([[dropZone draggedFilename] hasSuffix:@".jpg"] || [[dropZone draggedFilename] hasSuffix:@".jpeg"]) {
        content = [[[[dropZone draggedImage] representations] objectAtIndex:0] 
                                representationUsingType:NSJPEGFileType
                                             properties:nil];
    }
    else if ([[dropZone draggedFilename] hasSuffix:@".gif"]) {
        content = [[[[dropZone draggedImage] representations] objectAtIndex:0] 
                                representationUsingType:NSGIFFileType
                                             properties:nil];
    }
    else if ([[dropZone draggedFilename] hasSuffix:@".png"]) {
        content = [[[[dropZone draggedImage] representations] objectAtIndex:0] 
                                representationUsingType:NSPNGFileType
                                             properties:nil];
    }

    NSDictionary *params = [NSDictionary dictionaryWithObjectsAndKeys:
        username, @"username", 
        password, @"password", 
        content, @"content", 
        [customFilename stringValue], @"filename", 
        nil];
    
    NSArray *paramOrder = [NSArray arrayWithObjects:@"username", @"password", @"content", @"filename", nil];
    
    [progressSpinner startAnimation:self];
    
    NSArray *clickableSubviews = [[mainWindow contentView] subviews];
    NSEnumerator *subviewEnumerator = [clickableSubviews objectEnumerator];
    NSControl *thisControl;
    
    while (thisControl = [subviewEnumerator nextObject]) {        
        if ([thisControl class] == [NSButton class] || [thisControl class] == [NSTextField class]) {
            [thisControl setEnabled:NO];
        }
    }
    
    WebServicesWrapper *xmlrpc = [[[WebServicesWrapper alloc] init] autorelease];
    
    NSDictionary *result = [xmlrpc resultsForRequestWithURL:url
                                                     method:method
                                                 parameters:params
                                             parameterOrder:paramOrder];
    
    [progressSpinner stopAnimation:self];
    
    subviewEnumerator = [clickableSubviews objectEnumerator];

    while (thisControl = [subviewEnumerator nextObject]) {        
        if ([thisControl class] == [NSButton class] || [thisControl class] == [NSTextField class]) {
            [thisControl setEnabled:YES];
        }
    }    
    
    NSLog(@"%@", [result objectForKey:@"/Result"]);
    
    if ([[[result objectForKey:@"/Result"] objectAtIndex:0] intValue] == 1) {
        
        [[NSSound soundNamed:@"Glass"] play];
        
        [[NSPasteboard generalPasteboard] declareTypes:[NSArray arrayWithObject:NSStringPboardType]
                                                                          owner:nil];
        
        NSString *uploadURL = (NSString *)[[result objectForKey:@"/Result"] objectAtIndex:1];
        
        NSString *tagURL = [NSString stringWithFormat:@"<img src=\"%@\"/>", uploadURL];

        [[NSPasteboard generalPasteboard] setString:tagURL
                                            forType:NSStringPboardType];
        
        [[NSAlert alertWithMessageText:@"Your image was uploaded successfully!"
                         defaultButton:@"OK"
                       alternateButton:nil
                           otherButton:nil
             informativeTextWithFormat:@"Your image was uploaded successfully and an HTML image tag for it has been copied to the clipboard."] runModal];
        
        [self clickedClearPasteboard:self];
    }
    else {
        
        [[NSSound soundNamed:@"Basso"] play];
        
        [[NSAlert alertWithMessageText:@"There was an upload error!"
                        defaultButton:@"OK"
                      alternateButton:nil
                          otherButton:nil
            informativeTextWithFormat:@"There was a problem uploading your image. The server said: \"%@\"", 
                (NSString *)[[result objectForKey:@"/Result"] objectAtIndex:1]] runModal];
    }
}

- (IBAction)clickedClearPasteboard:(id)sender
{
    [customFilename setStringValue:@""];
    [dropZone clearPasteboard];
}

- (IBAction)clickedVisitAssets:(id)sender
{
    [[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:
        [[[NSUserDefaults standardUserDefaults] stringForKey:@"SiteURL"] stringByAppendingString:@"/assets/"]]];
}

- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)theApplication
{
    return YES;
}

- (BOOL)application:(NSApplication *)theApplication openFile:(NSString *)filename
{
    [dropZone updateForImageFile:filename];
    
    return YES;
}

@end