//
//  DragableImageView.m
//  Drupal XML-RPC Demo
//
//  Created by Justin R. Miller on 4/3/07.
//  Copyright 2007 Code Sorcery Workshop. All rights reserved.
//

#import "DragableImageView.h"

@implementation DragableImageView

- (NSString *)draggedFilename
{
    return draggedFilename;
}

- (NSImage *)draggedImage
{
    return draggedImage;
}

- (void)clearPasteboard
{
    if (draggedImage != [NSImage imageNamed:@"drupalDrop"]) {
        [draggedFilename release];
        [draggedImage release];
    }
    
    draggedFilename = nil;
    draggedImage = nil;
    
    [self setImageScaling:NSScaleToFit];
    [self setImage:[NSImage imageNamed:@"drupalDrop"]];
}

- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
{
    NSPasteboard *pasteBoard = [sender draggingPasteboard];
    
    if ([[pasteBoard types] containsObject:@"NSFilenamesPboardType"]) {
        if ([[pasteBoard propertyListForType:@"NSFilenamesPboardType"] count] == 1) {
            NSString *filename = [[pasteBoard propertyListForType:@"NSFilenamesPboardType"] objectAtIndex:0];
            if ([filename hasSuffix:@".jpg"] || 
                [filename hasSuffix:@".jpeg"] || 
                [filename hasSuffix:@".gif"] || 
                [filename hasSuffix:@".png"]) {
                return NSDragOperationCopy;
            }
        }            
    }   

    return NSDragOperationNone;
}

- (BOOL)performDragOperation:(id <NSDraggingInfo>)sender
{
    NSString *file = [[[sender draggingPasteboard] propertyListForType:@"NSFilenamesPboardType"] objectAtIndex:0];
    
    [self updateForImageFile:file];
    
    return YES;
}

- (void)updateForImageFile:(NSString *)filename
{
    [self clearPasteboard];
    
    draggedFilename = [filename retain];
    draggedImage = [[NSImage alloc] initWithContentsOfFile:draggedFilename];

    [self setImage:draggedImage];
    [self setImageScaling:NSScaleProportionally];
}

@end